@@ -65,6 +65,7 @@ package Sidef::Deparse::Perl {
                   Sidef::DataTypes::Glob::Backtick        Sidef::Types::Glob::Backtick
                   Sidef::DataTypes::Glob::DirHandle       Sidef::Types::Glob::DirHandle
                   Sidef::DataTypes::Glob::FileHandle      Sidef::Types::Glob::FileHandle
+                  Sidef::DataTypes::Glob::SocketHandle    Sidef::Types::Glob::SocketHandle
                   Sidef::DataTypes::Glob::Dir             Sidef::Types::Glob::Dir
                   Sidef::DataTypes::Glob::File            Sidef::Types::Glob::File
                   Sidef::DataTypes::Object::Object        Sidef::Object::Object
@@ -203,9 +204,9 @@ HEADER
         my ($self, $method) = @_;
 
         my $name = 'OP' . join('', unpack('C*', $method)) . refaddr($self);
-        my $line = "use constant $name=>\\" . $self->_dump_string($method) . ';';
+        my $line = "BEGIN { \$$self->{environment_name}\::$name = " . $self->_dump_string($method) . '};';
         $self->top_add($line);
-        '->${(' . $self->{environment_name} . '::' . $name . ')}';
+        '->$' . $self->{environment_name} . '::' . $name;
     }
 
     sub _dump_var {
@@ -966,18 +967,11 @@ HEADER
             }
         }
         elsif ($ref eq 'Sidef::Types::Number::Number') {
-            if ($obj->is_zero) {
-                $code = '(Sidef::Types::Number::Number::ZERO)';
-            }
-            elsif ($obj->is_one) {
-                $code = '(Sidef::Types::Number::Number::ONE)';
-            }
-            elsif ($obj->is_mone) {
-                $code = '(Sidef::Types::Number::Number::MONE)';
-            }
-            else {
-                $code = $self->make_constant($ref, '_set_str', "Number$refaddr", "'" . $obj->_get_frac . "'");
-            }
+            my ($sgn, $content) = $obj->_dump;
+            $code =
+                ($sgn == 2) ? $self->make_constant($ref, '_set_str',  "Number$refaddr", "'" . $content . "'")
+              : ($sgn >= 0) ? $self->make_constant($ref, '_new_uint', "Number$refaddr", "'" . $content . "'")
+              :               $self->make_constant($ref, '_new_int', "Number$refaddr", "'" . $content . "'");
         }
         elsif ($ref eq 'Sidef::Types::Number::Inf') {
             $code = $self->make_constant($ref, 'new', "Inf$refaddr");
@@ -1114,13 +1108,20 @@ HEADER
             $code = 'default' . $self->deparse_bare_block($obj->{block}->{code});
         }
         elsif ($ref eq 'Sidef::Types::Block::With') {
-            my $dvar = $self->_dump_var($obj->{block}{init_vars}->{vars}[0]);
-            $code =
-                'do{ if (defined(my '
-              . $dvar . '='
-              . $self->deparse_args($obj->{expr}) . ')) '
-              . $self->deparse_bare_block($obj->{block}{code})
-              . ' else { } }';
+            $code = 'do{';
+            foreach my $i (0 .. $#{$obj->{with}}) {
+                $code .= ($i == 0 ? 'if' : 'elsif');
+                my $info = $obj->{with}[$i];
+                my $dvar = $self->_dump_var($info->{block}{init_vars}->{vars}[0]);
+                $code .=
+                    "(defined(my $dvar = do{"
+                  . $self->deparse_args($info->{expr}) . '}))'
+                  . $self->deparse_bare_block($info->{block}{code});
+            }
+            if (exists $obj->{else}) {
+                $code .= 'else' . $self->deparse_bare_block($obj->{else}{block}{code});
+            }
+            $code .= '}';
         }
         elsif ($ref eq 'Sidef::Types::Block::Gather') {
             $self->load_mod("Sidef::Types::Array::Array");
@@ -1163,22 +1164,22 @@ HEADER
             $code = $self->make_constant($ref, 'new', "Math$refaddr");
         }
         elsif ($ref eq 'Sidef::Meta::Glob::STDIN') {
-            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new', "STDIN$refaddr", 'fh => \*STDIN');
+            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new', "STDIN$refaddr", '\*STDIN');
         }
         elsif ($ref eq 'Sidef::Meta::Glob::STDOUT') {
-            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new', "STDOUT$refaddr", 'fh => \*STDOUT');
+            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new', "STDOUT$refaddr", '\*STDOUT');
         }
         elsif ($ref eq 'Sidef::Meta::Glob::STDERR') {
-            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new', "STDERR$refaddr", 'fh => \*STDERR');
+            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new', "STDERR$refaddr", '\*STDERR');
         }
         elsif ($ref eq 'Sidef::Meta::Glob::ARGF') {
-            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new', "ARGF$refaddr", 'fh => \*ARGV');
+            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new', "ARGF$refaddr", '\*ARGV');
         }
         elsif ($ref eq 'Sidef::Meta::Glob::DATA') {
             require Encode;
             my $data = $self->_dump_string(Encode::encode_utf8(${$obj->{data}}));
-            $code = $self->make_constant('Sidef::Types::Glob::FileHandle',
-                                         'new', "DATA$refaddr", qq{fh => do{open my \$fh, '<:utf8', \\$data; \$fh}});
+            $code = $self->make_constant('Sidef::Types::Glob::FileHandle', 'new',
+                                         "DATA$refaddr",                   qq{do{open my \$fh, '<:utf8', \\$data; \$fh}});
         }
         elsif ($ref eq 'Sidef::Variable::Magic') {
             $code = $obj->{name};
@@ -1211,11 +1212,12 @@ HEADER
             $code = $self->make_constant($ref, 'new', "Sig$refaddr");
         }
         elsif ($ref eq 'Sidef::Types::Number::Complex') {
-
-            # TODO: optimize this
-            $code = $self->make_constant($ref, 'new', "Complex$refaddr",
-                                         "'" . $obj->re->get_value . "'",
-                                         "'" . $obj->im->get_value . "'");
+            my ($real, $imag) = $obj->parts;
+            my $name = "Complex$refaddr";
+            $self->top_add(  "use constant $name => $ref\->new("
+                           . join(',', $self->deparse_expr({self => $real}), $self->deparse_expr({self => $imag}))
+                           . ');');
+            $code = "($self->{environment_name}\::$name)";
         }
         elsif ($ref eq 'Sidef::Types::Array::Pair') {
             $code =
@@ -1231,8 +1233,14 @@ HEADER
             $code = $self->make_constant($ref, '__NEW__', "MOD_F$refaddr", $self->_dump_string($obj->{module}));
         }
         elsif ($ref eq 'Sidef::Types::Range::RangeNumber' or $ref eq 'Sidef::Types::Range::RangeString') {
-            $code = $self->make_constant($ref, 'new', "Range$refaddr",
-                       map { 'Sidef::Types::Number::Number->_set_str(' . $obj->{$_}->_get_frac . ')' } ('from', 'to', 'step'));
+            $code = $self->make_constant(
+                $ref, 'new',
+                "Range$refaddr",
+                map {
+                    'Sidef::Types::Number::Number->_set_str(' . "'"
+                      . $obj->{$_}->_get_frac . "'" . ')'
+                  } ('from', 'to', 'step')
+            );
         }
         elsif ($ref eq 'Sidef::Types::Glob::Backtick') {
             $code = $self->make_constant($ref, 'new', "Backtick$refaddr", $self->_dump_string(${$obj}));
