@@ -36,6 +36,7 @@ package Sidef::Deparse::Sidef {
                   Sidef::DataTypes::Glob::Backtick        Backtick
                   Sidef::DataTypes::Glob::DirHandle       DirHandle
                   Sidef::DataTypes::Glob::FileHandle      FileHandle
+                  Sidef::DataTypes::Glob::SocketHandle    SocketHandle
                   Sidef::DataTypes::Glob::Dir             Dir
                   Sidef::DataTypes::Glob::File            File
                   Sidef::DataTypes::Object::Object        Object
@@ -454,7 +455,14 @@ package Sidef::Deparse::Sidef {
             $code = 'default' . $self->deparse_bare_block($obj->{block}->{code});
         }
         elsif ($ref eq 'Sidef::Types::Block::With') {
-            $code = 'with ' . $self->deparse_args($obj->{expr}) . $self->deparse_expr({self => $obj->{block}});
+            foreach my $i (0 .. $#{$obj->{with}}) {
+                $code .= ($i == 0 ? 'with' : 'orwith');
+                my $info = $obj->{with}[$i];
+                $code .= $self->deparse_args($info->{expr}) . $self->deparse_expr({self => $info->{block}});
+            }
+            if (exists $obj->{else}) {
+                $code .= 'else' . $self->deparse_bare_block($obj->{else}{block}{code});
+            }
         }
         elsif ($ref eq 'Sidef::Types::Block::Return') {
             if (not exists $expr->{call}) {
