@@ -281,7 +281,8 @@ package Sidef::Object::Object {
     }
 
     sub interpolate {
-        $_[0]->new(CORE::join('', @_[1 .. $#_]));
+        my $self = shift(@_);
+        $self->new(CORE::join('', @_));
     }
 
     sub dump {
@@ -360,8 +361,10 @@ package Sidef::Object::Object {
                 $methods{$method} = (
                                      $alias{\&{$ref . '::' . $method}} //=
                                        Sidef::Object::LazyMethod->new(
-                                                                      obj    => $self,
-                                                                      method => \&{$ref . '::' . $method}
+                                                                      {
+                                                                       obj    => $self,
+                                                                       method => $method,
+                                                                      }
                                                                      )
                                     );
             }
