@@ -19,7 +19,10 @@ package Sidef::Types::Array::Array {
     sub new {
         @_ == 2 && ref($_[1]) eq 'ARRAY'
           ? bless($_[1], __PACKAGE__)
-          : bless [@_[1 .. $#_]], __PACKAGE__;
+          : do {
+            shift(@_);
+            bless [@_], __PACKAGE__;
+          };
     }
 
     *call = \&new;
@@ -477,14 +480,14 @@ package Sidef::Types::Array::Array {
                 }
             }
 
-            return Sidef::Types::Number::Number::_new_uint($counter);
+            return Sidef::Types::Number::Number->_new_uint($counter);
         }
 
         foreach my $item (@{$self}) {
             $item eq $obj and $counter++;
         }
 
-        Sidef::Types::Number::Number::_new_uint($counter);
+        Sidef::Types::Number::Number->_new_uint($counter);
     }
 
     *count_by = \&count;
@@ -869,7 +872,7 @@ package Sidef::Types::Array::Array {
         my ($self, $code) = @_;
 
         foreach my $i (0 .. $#{$self}) {
-            $code->run(Sidef::Types::Number::Number::_new_uint($i));
+            $code->run(Sidef::Types::Number::Number->_new_uint($i));
         }
 
         $self;
@@ -881,7 +884,7 @@ package Sidef::Types::Array::Array {
         my ($self, $code) = @_;
 
         foreach my $i (0 .. $#{$self}) {
-            $code->run(Sidef::Types::Number::Number::_new_uint($i), $self->[$i]);
+            $code->run(Sidef::Types::Number::Number->_new_uint($i), $self->[$i]);
         }
 
         $self;
@@ -903,7 +906,7 @@ package Sidef::Types::Array::Array {
 
         my @arr;
         foreach my $i (0 .. $#{$self}) {
-            CORE::push(@arr, $code->run(Sidef::Types::Number::Number::_new_uint($i), $self->[$i]));
+            CORE::push(@arr, $code->run(Sidef::Types::Number::Number->_new_uint($i), $self->[$i]));
         }
 
         $self->new(\@arr);
@@ -945,7 +948,7 @@ package Sidef::Types::Array::Array {
 
         my @arr;
         foreach my $i (0 .. $#{$self}) {
-            CORE::push(@arr, $self->[$i]) if $code->run(Sidef::Types::Number::Number::_new_uint($i), $self->[$i]);
+            CORE::push(@arr, $self->[$i]) if $code->run(Sidef::Types::Number::Number->_new_uint($i), $self->[$i]);
         }
 
         $self->new(\@arr);
@@ -993,7 +996,7 @@ package Sidef::Types::Array::Array {
         }
 
         foreach my $key (keys %hash) {
-            $hash{$key} = Sidef::Types::Number::Number::_new_uint($hash{$key});
+            $hash{$key} = Sidef::Types::Number::Number->_new_uint($hash{$key});
         }
 
         Sidef::Types::Hash::Hash->new(%hash);
@@ -1008,7 +1011,7 @@ package Sidef::Types::Array::Array {
         }
 
         foreach my $key (keys %hash) {
-            $hash{$key} = Sidef::Types::Number::Number::_new_uint($hash{$key});
+            $hash{$key} = Sidef::Types::Number::Number->_new_uint($hash{$key});
         }
 
         Sidef::Types::Hash::Hash->new(%hash);
@@ -1078,14 +1081,14 @@ package Sidef::Types::Array::Array {
             if (ref($obj) eq 'Sidef::Types::Block::Block') {
                 foreach my $i (0 .. $#{$self}) {
                     $obj->run($self->[$i])
-                      && return Sidef::Types::Number::Number::_new_uint($i);
+                      && return Sidef::Types::Number::Number->_new_uint($i);
                 }
                 return Sidef::Types::Number::Number::MONE;
             }
 
             foreach my $i (0 .. $#{$self}) {
                 $self->[$i] eq $obj
-                  and return Sidef::Types::Number::Number::_new_uint($i);
+                  and return Sidef::Types::Number::Number->_new_uint($i);
             }
 
             return Sidef::Types::Number::Number::MONE;
@@ -1106,7 +1109,7 @@ package Sidef::Types::Array::Array {
             if (ref($obj) eq 'Sidef::Types::Block::Block') {
                 for (my $i = $#{$self} ; $i >= 0 ; $i--) {
                     $obj->run($self->[$i])
-                      && return Sidef::Types::Number::Number::_new_uint($i);
+                      && return Sidef::Types::Number::Number->_new_uint($i);
                 }
 
                 return Sidef::Types::Number::Number::MONE;
@@ -1114,7 +1117,7 @@ package Sidef::Types::Array::Array {
 
             for (my $i = $#{$self} ; $i >= 0 ; $i--) {
                 $self->[$i] eq $obj
-                  and return Sidef::Types::Number::Number::_new_uint($i);
+                  and return Sidef::Types::Number::Number->_new_uint($i);
             }
 
             return Sidef::Types::Number::Number::MONE;
@@ -1191,7 +1194,7 @@ package Sidef::Types::Array::Array {
 
     sub length {
         my ($self) = @_;
-        Sidef::Types::Number::Number::_new_uint(scalar @{$self});
+        Sidef::Types::Number::Number->_new_uint(scalar @{$self});
     }
 
     *len  = \&length;    # alias
@@ -1202,8 +1205,8 @@ package Sidef::Types::Array::Array {
             $end == -1 ? Sidef::Types::Number::Number::MONE
           : $end == 0  ? Sidef::Types::Number::Number::ZERO
           : $end == 1  ? Sidef::Types::Number::Number::ONE
-          : $end > 0   ? Sidef::Types::Number::Number::_new_uint($end)
-          :              Sidef::Types::Number::Number::_new_int($end);
+          : $end > 0   ? Sidef::Types::Number::Number->_new_uint($end)
+          :              Sidef::Types::Number::Number->_new_int($end);
     }
 
     *offset = \&end;
@@ -1234,14 +1237,14 @@ package Sidef::Types::Array::Array {
     sub range {
         my ($self) = @_;
         Sidef::Types::Range::RangeNumber->new(Sidef::Types::Number::Number::ZERO,
-                                              Sidef::Types::Number::Number::_new_int($#{$self}),
+                                              Sidef::Types::Number::Number->_new_int($#{$self}),
                                               Sidef::Types::Number::Number::ONE,
                                              );
     }
 
     sub indices {
         my ($self) = @_;
-        $self->new([map { Sidef::Types::Number::Number::_new_uint($_) } 0 .. $#{$self}]);
+        $self->new([map { Sidef::Types::Number::Number->_new_uint($_) } 0 .. $#{$self}]);
     }
 
     *keys = \&indices;
@@ -1249,7 +1252,7 @@ package Sidef::Types::Array::Array {
     sub pairs {
         my ($self) = @_;
         $self->new(
-            [map { Sidef::Types::Array::Pair->new(Sidef::Types::Number::Number::_new_uint($_), $self->[$_]) } 0 .. $#{$self}]);
+            [map { Sidef::Types::Array::Pair->new(Sidef::Types::Number::Number->_new_uint($_), $self->[$_]) } 0 .. $#{$self}]);
     }
 
     sub insert {
