@@ -52,14 +52,14 @@ package Sidef::Types::Range::Range {
 
     sub min {
         my ($self) = @_;
-        $self->{step}->is_pos
+        ($self->{_asc} //= !!$self->{step}->is_pos)
           ? $self->{from}
           : $self->{to};
     }
 
     sub max {
         my ($self) = @_;
-        $self->{step}->is_pos
+        ($self->{_asc} //= !!$self->{step}->is_pos)
           ? $self->{to}
           : $self->{from};
     }
@@ -121,7 +121,7 @@ package Sidef::Types::Range::Range {
         my ($self, $value) = @_;
 
         my $step = $self->{step};
-        my $asc  = !!($step->is_pos);
+        my $asc = ($self->{_asc} //= !!$step->is_pos);
 
         my ($from, $to) = (
                            $asc
@@ -130,18 +130,20 @@ package Sidef::Types::Range::Range {
                           );
 
         (
-         $value->ge($from) and $value->le($to)
+               $value->ge($from)
+           and $value->le($to)
            and (
-                $step->abs->is_one && $value->is_int ? 1
-                : $value->sub(
-                                $asc ? $from
-                              : $to
-                )->div($step)->int->mul($step)->eq(
-                                                   $value->sub(
-                                                                 $asc ? $from
-                                                               : $to
-                                                              )
-                                                  )
+             do { $self->{_is_one} //= ($asc ? $step->is_one : $step->abs->is_one) }
+             && $value->is_int ? 1
+             : $value->sub(
+                             $asc ? $from
+                           : $to
+             )->div($step)->int->mul($step)->eq(
+                                                $value->sub(
+                                                              $asc ? $from
+                                                            : $to
+                                                           )
+                                               )
                )
           ) ? (Sidef::Types::Bool::Bool::TRUE)
           : (Sidef::Types::Bool::Bool::FALSE);
@@ -302,7 +304,7 @@ package Sidef::Types::Range::Range {
                 ++$count if $arg->run($obj);
             }
 
-            return Sidef::Types::Number::Number::_new_uint($count);
+            return Sidef::Types::Number::Number->_new_uint($count);
         }
 
         $self->contains($arg)
