@@ -20,7 +20,8 @@ package Sidef::Types::String::String {
     sub new {
         my (undef, $str) = @_;
         if (@_ > 2) {
-            $str = CORE::join('', map { "$_" } @_[1 .. $#_]);
+            shift(@_);
+            $str = CORE::join('', @_);
         }
         bless(\"$str", __PACKAGE__);
     }
@@ -388,7 +389,7 @@ package Sidef::Types::String::String {
 
     sub index {
         my ($self, $substr, $pos) = @_;
-        Sidef::Types::Number::Number::_new_int(
+        Sidef::Types::Number::Number->_new_int(
                                                defined($pos)
                                                ? CORE::index($$self, "$substr", CORE::int($pos))
                                                : CORE::index($$self, "$substr")
@@ -397,7 +398,7 @@ package Sidef::Types::String::String {
 
     sub rindex {
         my ($self, $substr, $pos) = @_;
-        Sidef::Types::Number::Number::_new_int(
+        Sidef::Types::Number::Number->_new_int(
                                                defined($pos)
                                                ? CORE::rindex($$self, "$substr", CORE::int($pos))
                                                : CORE::rindex($$self, "$substr")
@@ -408,7 +409,7 @@ package Sidef::Types::String::String {
         my ($self) = @_;
         $$self eq ''
           ? Sidef::Types::Number::Nan::NAN
-          : Sidef::Types::Number::Number::_new_uint(CORE::ord($$self));
+          : Sidef::Types::Number::Number->_new_uint(CORE::ord($$self));
     }
 
     sub reverse {
@@ -527,6 +528,16 @@ package Sidef::Types::String::String {
         Sidef::Types::Array::Array->new([map { bless(\$_, __PACKAGE__) } $str =~ /$regex->{regex}/g]);
     }
 
+    sub findall {
+        my ($self, $regex) = @_;
+        my $str = $$self;
+        my @matches;
+        while ($str =~ /$regex->{regex}/g) {
+            push @matches, Sidef::Types::Array::Array->new([_get_captures($str)]);
+        }
+        Sidef::Types::Array::Array->new(\@matches);
+    }
+
     sub split {
         my ($self, $sep, $size) = @_;
 
@@ -616,7 +627,7 @@ package Sidef::Types::String::String {
         Sidef::Types::Array::Array->new(
             [
              map {
-                 Sidef::Types::Number::Number::_new_uint(CORE::ord(bytes::substr($string, $_, 1)))
+                 Sidef::Types::Number::Number->_new_uint(CORE::ord(bytes::substr($string, $_, 1)))
                } 0 .. bytes::length($string) - 1
             ]
         );
@@ -629,7 +640,7 @@ package Sidef::Types::String::String {
 
         state $x = require bytes;
         foreach my $i (0 .. bytes::length($string) - 1) {
-            $code->run(Sidef::Types::Number::Number::_new_uint(CORE::ord bytes::substr($string, $i, 1)));
+            $code->run(Sidef::Types::Number::Number->_new_uint(CORE::ord bytes::substr($string, $i, 1)));
         }
 
         $self;
@@ -703,6 +714,16 @@ package Sidef::Types::String::String {
         $self;
     }
 
+    sub pipe {
+        my ($self) = @_;
+        Sidef::Types::Glob::Pipe->new($$self);
+    }
+
+    sub backtick {
+        my ($self) = @_;
+        Sidef::Types::Glob::Backtick->new($$self);
+    }
+
     sub open_r {
         my ($self, @rest) = @_;
         state $x = require Encode;
@@ -791,7 +812,7 @@ package Sidef::Types::String::String {
     }
 
     sub chars_length {
-        Sidef::Types::Number::Number::_new_uint(CORE::length(${$_[0]}));
+        Sidef::Types::Number::Number->_new_uint(CORE::length(${$_[0]}));
     }
 
     *len       = \&chars_length;
@@ -800,7 +821,7 @@ package Sidef::Types::String::String {
     *size      = \&chars_length;
 
     sub graphs_length {
-        Sidef::Types::Number::Number::_new_uint(scalar(() = ${$_[0]} =~ /\X/g));
+        Sidef::Types::Number::Number->_new_uint(scalar(() = ${$_[0]} =~ /\X/g));
     }
 
     *graphs_len = \&graphs_length;
@@ -809,7 +830,7 @@ package Sidef::Types::String::String {
         my ($self) = @_;
 
         state $x = require bytes;
-        Sidef::Types::Number::Number::_new_uint(bytes::length($$self));
+        Sidef::Types::Number::Number->_new_uint(bytes::length($$self));
     }
 
     *bytes_len = \&bytes_length;
@@ -835,7 +856,7 @@ package Sidef::Types::String::String {
             }
         }
 
-        Sidef::Types::Number::Number::_new_int($d[-1][-1]);
+        Sidef::Types::Number::Number->_new_int($d[-1][-1]);
     }
 
     *lev   = \&levenshtein;
@@ -942,18 +963,18 @@ package Sidef::Types::String::String {
         if (ref($arg) eq 'Sidef::Types::Regex::Regex') {
             my $regex = $arg->{regex};
             ++$counter while $s =~ /$regex/g;
-            return Sidef::Types::Number::Number::_new_uint($counter);
+            return Sidef::Types::Number::Number->_new_uint($counter);
         }
         elsif (ref($arg) eq 'Sidef::Types::Block::Block') {
             foreach my $char (split //, $s) {
                 ++$counter if $arg->run(bless(\$char, __PACKAGE__));
             }
-            return Sidef::Types::Number::Number::_new_uint($counter);
+            return Sidef::Types::Number::Number->_new_uint($counter);
         }
 
         my $ss = "$arg";
         ++$counter while $s =~ /\Q$ss\E/g;
-        Sidef::Types::Number::Number::_new_uint($counter);
+        Sidef::Types::Number::Number->_new_uint($counter);
     }
 
     sub overlaps {
@@ -1077,7 +1098,7 @@ package Sidef::Types::String::String {
     sub apply_escapes {
         my ($self, $parser) = @_;
 
-        $$self =~ /\\|#\{/ || return $self;    # fast exit
+        $$self =~ /\\|#\{/ || return $self;    # return faster
 
         state $x = require Encode;
         my $str = $$self;
@@ -1239,12 +1260,14 @@ package Sidef::Types::String::String {
                 splice @chars, $pair->[0] + $i, 0, $pair->[1];
             }
 
-            state $str_dt = bless({}, 'Sidef::DataTypes::String::String');
+            state %cache;
+            my $type = (ref($self) =~ s/::Types::/::DataTypes::/r);
+            my $dt = ($cache{$type} //= bless({}, $type));
 
             my $expr = {
                         $parser->{class} => [
                                              {
-                                              self => $str_dt,
+                                              self => $dt,
                                               call => [{method => 'interpolate'}]
                                              }
                                             ]
